class NotFoundError(Exception):
    ...


class IndexDoesNotFoundError(Exception):
    ...


class InvalidElasticsearchResponse(Exception):
    ...


class InvalidModelError(Exception):
    ...


class BulkError(Exception):
    ...
